"""
This module defines the test argument information list for cqadm.py and will 
dynamically be imported by testutils.py to generate the tests for cqadm.py.

Refer to the TESTUTILS_README.txt for more information about the usage of this module and testutils.py

test_argslist - is a list of dictionaries, each dictionary has all the necessary info for a test.

"""

test_argslist = [
    { "tc_name" : "getq_option_1", "args" : """--getq""", },
    { "tc_name" : "getq_option_2", "args" : """-d --getq""", },
    { "tc_name" : "getq_option_3", "args" : """-f --getq""", },
    { "tc_name" : "preempt_job_1", "args" : """-d --preempt 1 2 3""", },
    { "tc_name" : "preempt_job_2", "args" : """-f --preempt 1 2 3""", },
    { "tc_name" : "kill_job_1", "args" : """-d -f --kill 1 2 3""", "old_args" : """--delete 1 2 3""", },
    { "tc_name" : "kill_job_2", "args" : """--kill 1 2 3""", },
    { "tc_name" : "kill_job_3", "args" : """-f --kill 1 2 3""", "old_args" : """-d --delete 1 2 3""", },
    { "tc_name" : "kill_job_4", "args" : """-d --kill 1 2 3""", },
    { "tc_name" : "addq_option_1", "args" : """--addq""", "old_args" : "", },
    { "tc_name" : "addq_option_2", "args" : """--addq myq1 myq2 myq3""", },
    { "tc_name" : "delq_option_1", "args" : """--delq""", "old_args" : "", },
    { "tc_name" : "delq_option_2", "args" : """--delq myq1 myq2 myq3""", },
    { "tc_name" : "stopq_option_1", "args" : """--stopq""", "old_args" : "", },
    { "tc_name" : "stopq_option_2", "args" : """--stopq myq1 myq2 myq3""", },
    { "tc_name" : "startq_option_1", "args" : """--startq""", "old_args" : "", },
    { "tc_name" : "startq_option_2", "args" : """--startq myq1 myq2 myq3""", },
    { "tc_name" : "drainq_option_1", "args" : """--drainq""", "old_args" : "", },
    { "tc_name" : "drainq_option_2", "args" : """--drainq myq1 myq2 myq3""", },
    { "tc_name" : "killq_option_1", "args" : """--killq""", "old_args" : "", },
    { "tc_name" : "killq_option_2", "args" : """--killq myq1 myq2 myq3""", },
    { "tc_name" : "policy_option_1", "args" : """--policy""", },
    { "tc_name" : "policy_option_2", "args" : """--policy 'mypolicy'""", "old_args" : "", },
    { "tc_name" : "policy_option_3", "args" : """--policy 'mypolicy' myq1 myq2""", },
    { "tc_name" : "setq_option_1", "args" : """--setq""", },
    { "tc_name" : "setq_option_2", "args" : """--setq 'a=b b=c a=c'""", "old_args" : "", },
    { "tc_name" : "setq_option_3", "args" : """--setq 'a=b b=c a=c' myq1 myq2""", },
    { "tc_name" : "unsetq_option_1", "args" : """--unsetq""", },
    { "tc_name" : "unsetq_option_2", "args" : """--unsetq 'a b a'""", "old_args" : "", },
    { "tc_name" : "unsetq_option_3", "args" : """--unsetq 'a b a' myq1 myq2""", },
    { "tc_name" : "setjobid_option_1", "args" : """-j""", },
    { "tc_name" : "setjobid_option_2", "args" : """--setjobid""", },
    { "tc_name" : "setjobid_option_3", "args" : """-j 1""", },
    { "tc_name" : "setjobid_option_4", "args" : """--setjobid 1""", },
    { "tc_name" : "setjobid_option_5", "args" : """-j 1 --setjobid 2""", },
    { "tc_name" : "run_option_1", "args" : """--run""", },
    { "tc_name" : "run_option_2", "args" : """--run mayaguez""", "old_args" : "", },
    { "tc_name" : "run_option_3", "args" : """--run mayaguez 1 2 3""", },
    { "tc_name" : "hold_option_1", "args" : """--hold""", },
    { "tc_name" : "hold_option_2", "args" : """--hold 1 2 3""", },
    { "tc_name" : "hold_option_3", "args" : """-d --hold  1 2 3""", },
    { "tc_name" : "hold_option_4", "args" : """-f --hold  1 2 3""", },
    { "tc_name" : "release_option_1", "args" : """--release""", },
    { "tc_name" : "release_option_2", "args" : """--release 1 2 3""", },
    { "tc_name" : "release_option_3", "args" : """-d --release 1 2 3""", },
    { "tc_name" : "release_option_4", "args" : """-f --release 1 2 3""", },
    { "tc_name" : "release_and_hold", "args" : """--hold --release 1 2 3""", },
    { "tc_name" : "queue_option_1", "args" : """--queue""", },
    { "tc_name" : "queue_option_2", "args" : """--queue myq""", "old_args" : "", },
    { "tc_name" : "queue_option_3", "args" : """--queue myq 1 2 3""", },
    { "tc_name" : "time_option_1", "args" : """--time""", },
    { "tc_name" : "time_option_2", "args" : """--time 50""", "old_args" : "", },
    { "tc_name" : "time_option_4", "args" : """--time 50 1 2 3""", },
    { "tc_name" : "update_all_1", "args" : """--hold --queue myq --time 50 4 5 6""", },
    { "tc_name" : "update_all_2", "args" : """--release --queue myq --time 50 4 5 6""", },
    { "tc_name" : "combine_getq_and_addq", "args" : """--getq --addq myq1 myq2 myq3""", "old_args" : "", },
    { "tc_name" : "combine_getq_and_setjobid", "args" : """--getq -j 1 123""", "old_args" : "", },
    { "tc_name" : "combine_time_and_getq", "args" : """--time 50 --getq""", "old_args" : "", },
    { "tc_name" : "combine_release_and_getq", "args" : """--release --getq 123""", "old_args" : "", },
    { "tc_name" : "combine_setq_with_queue", "args" : """--setq 'a=1 b=2' --queue q 1""", "old_args" : "", },
    { "tc_name" : "combine_addq_and_delq", "args" : """--addq --delq q1 q2""", "old_args" : "", },
    { "tc_name" : "combine_addq_and_stopq", "args" : """--stopq --addq q1 q2""", "old_args" : "", },
    { "tc_name" : "combine_addq_and_startq", "args" : """--startq --addq q1 q2""", "old_args" : "", },
    ]
